/**
 * @file
 *
 * Javascript functionalities for the search bar in a block.
 */
(function ($) {

  Drupal.behaviors.sonr_webmining_block_search_bar = {
    attach: function (context, settings) {

      $("div.sonr-webmining-block-search-bar", context).once('sonr_webmining_block_search_bar', function () {
        var input = $("input", this);

        // Search for free terms.
        var search_types = input.data("search-type").split(" ");
        $(this).closest("form").submit(function (event) {
          // Check if searching for free terms is activated.
          if ($.inArray("free-term", search_types) !== -1) {
            window.location.href = Drupal.settings.basePath + input.data("page-path") + '?search=' + input.val();
          }
          event.preventDefault();
        });

        // Clear the input field on focus.
        input.focus(function() {
          input.val("");
        });

        // Add the autocomplete functionality to the input field.
        input.autocomplete({
          minLength: input.data("min-chars"),
          source: function (request, response) {
            var url = Drupal.settings.basePath + input.data("autocomplete-path");
            $.getJSON(url, {term: request.term}, function (data) {
              input.removeClass("throbbing");
              response(data);
            });
          },
          search: function (event, ui) {
            input.addClass("throbbing");
          },
          focus: function (event, ui) {
            this.value = ui.item.label;
            return false;
          },
          select: function (event, ui) {
            this.value = ui.item.label;
            window.location.href = Drupal.settings.basePath + input.data("page-path") + '?uri=' + ui.item.value;
            return false;
          }
        });
      });

    }
  };

})(jQuery);
